pyMez.Code.DataHandlers API documentation
Description: DataHandlers ------------ The DataHandlers subpackage is designed to manipulate data, by allowing di...

Top

# pyMez.Code.DataHandlers module

## DataHandlers

The DataHandlers subpackage is designed to manipulate data, by allowing different data types to be opened, created, saved and updated. The subpackage is further divided into modules grouped by a common theme. Classes for data that are already on disk normally follows the following pattern: `instance=ClassName(file_path,**options)` For Example to open a XML file that you don't know the model, use `xml=pyMez.Code.DataHandlers.XMLModels.XMLBase('MyXML.xml')' or`xml=XMLBase('MyXML.xml')`

All data models normally have save(), str() and if appropriate show() methods.

## Import Structure

DataHandlers typically import from Utils but NOT from Analysis, InstrumentControl or FrontEnds

## Examples

How to open a s2p file

Show source ≡

    """
    DataHandlers
    ------------
    The DataHandlers subpackage is designed to manipulate data, by allowing different data types to be opened,
    created, saved and updated. The subpackage is further divided into modules grouped by a common theme. Classes for data
    that are already on disk normally follows the following pattern:
    `instance=ClassName(file_path,**options)`
    For Example to
    open a XML file that you don't know the model, use
    `xml=pyMez.Code.DataHandlers.XMLModels.XMLBase('MyXML.xml')'
    or
    `xml=XMLBase('MyXML.xml')`

    All data models normally have save(), str() and if appropriate show() methods.

    Import Structure
    ----------------
    DataHandlers typically import from Utils but __NOT__ from Analysis, InstrumentControl or FrontEnds

    Examples
    --------
    <a href="../../../Examples/How_To_Open_S2p.html"> How to open a s2p file </a>

    """

## Sub-modules

pyMez.Code.DataHandlers.GeneralModels

Module that contains general data models and functions for handling them

pyMez.Code.DataHandlers.GraphModels

Graph Models stores sub classes of graphs that define data translations

pyMez.Code.DataHandlers.HTMLModels

HTMLModels is a module for the creation and manipulation of HTML based models

pyMez.Code.DataHandlers.MUFModels

A module that holds the models associated with the Microwave Uncertainty Framework. Most models are xml based

pyMez.Code.DataHandlers.NISTModels

NISTModels is a module to handle data types found at NIST in Boulder, CO

pyMez.Code.DataHandlers.RadiCALModels

Handles the data saved after running Radical to analyze data. The assumed format is .mat V7.3, if saved in the older format, resave by setting preferences in matlab Environment->Preferences->General->MAT-Files->V7.3. This stores the result as an hd5 file with a .mat extension. Previous versions of m...

pyMez.Code.DataHandlers.StatistiCALModels

A wrapper for the StatistiCAL com object and some python classes and functions for interacting with it. More information on statistical can be found at http://www.nist.gov/ctl/rf-technology/related-software.cfm

pyMez.Code.DataHandlers.TouchstoneModels

A module dedicated to the manipulation and storage of touchstone files, such as .s2p or .ts files. Touchstone files are normally s-parameter data for multiport VNA's This module handles all SNP's and different formats such as MA, DB, RI. It currently does not support T, Y, and Z transformations. On ...

pyMez.Code.DataHandlers.Translations

Translations.py holds stateless functions that map from one form to another. Warning!!! The functions defined in this module break from normal naming practices to better reflect their purpose. A translation from one object or file takes the form UpperCamelCase_to_UpperCamelCase This change is meant ...

pyMez.Code.DataHandlers.XMLModels

XMLModels is dedicated to handling xml based models, requires lxml to be installed. see also `pyMez.Code.DataHandlers.HTMLModels`

pyMez.Code.DataHandlers.ZipModels

ZipModels holds classes and functions for manipulating zip files